==> javax.swing-1.0.2.jar: javax/swing/text/html/HTML$Attribute.clj <==
(ns javax.swing.text.html.HTML$Attribute
  "Typesafe enumeration representing an HTML
  attribute."
  (:refer-clojure :only [require comment defn ->])
  (:import [javax.swing.text.html HTML$Attribute]))

(def *-size
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/SIZE)

(def *-color
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/COLOR)

(def *-clear
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CLEAR)

(def *-background
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/BACKGROUND)

(def *-bgcolor
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/BGCOLOR)

(def *-text
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/TEXT)

(def *-link
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/LINK)

(def *-vlink
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/VLINK)

(def *-alink
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ALINK)

(def *-width
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/WIDTH)

(def *-height
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/HEIGHT)

(def *-align
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ALIGN)

(def *-name
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/NAME)

(def *-href
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/HREF)

(def *-rel
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/REL)

(def *-rev
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/REV)

(def *-title
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/TITLE)

(def *-target
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/TARGET)

(def *-shape
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/SHAPE)

(def *-coords
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/COORDS)

(def *-ismap
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ISMAP)

(def *-nohref
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/NOHREF)

(def *-alt
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ALT)

(def *-id
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ID)

(def *-src
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/SRC)

(def *-hspace
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/HSPACE)

(def *-vspace
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/VSPACE)

(def *-usemap
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/USEMAP)

(def *-lowsrc
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/LOWSRC)

(def *-codebase
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CODEBASE)

(def *-code
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CODE)

(def *-archive
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ARCHIVE)

(def *-value
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/VALUE)

(def *-valuetype
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/VALUETYPE)

(def *-type
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/TYPE)

(def *-class
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CLASS)

(def *-style
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/STYLE)

(def *-lang
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/LANG)

(def *-face
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/FACE)

(def *-dir
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/DIR)

(def *-declare
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/DECLARE)

(def *-classid
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CLASSID)

(def *-data
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/DATA)

(def *-codetype
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CODETYPE)

(def *-standby
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/STANDBY)

(def *-border
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/BORDER)

(def *-shapes
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/SHAPES)

(def *-noshade
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/NOSHADE)

(def *-compact
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/COMPACT)

(def *-start
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/START)

(def *-action
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ACTION)

(def *-method
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/METHOD)

(def *-enctype
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ENCTYPE)

(def *-checked
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CHECKED)

(def *-maxlength
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/MAXLENGTH)

(def *-multiple
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/MULTIPLE)

(def *-selected
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/SELECTED)

(def *-rows
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ROWS)

(def *-cols
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/COLS)

(def *-dummy
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/DUMMY)

(def *-cellspacing
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CELLSPACING)

(def *-cellpadding
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CELLPADDING)

(def *-valign
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/VALIGN)

(def *-halign
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/HALIGN)

(def *-nowrap
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/NOWRAP)

(def *-rowspan
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ROWSPAN)

(def *-colspan
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/COLSPAN)

(def *-prompt
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/PROMPT)

(def *-httpequiv
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/HTTPEQUIV)

(def *-content
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CONTENT)

(def *-language
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/LANGUAGE)

(def *-version
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/VERSION)

(def *-n
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/N)

(def *-frameborder
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/FRAMEBORDER)

(def *-marginwidth
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/MARGINWIDTH)

(def *-marginheight
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/MARGINHEIGHT)

(def *-scrolling
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/SCROLLING)

(def *-noresize
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/NORESIZE)

(def *-endtag
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ENDTAG)

(def *-comment
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/COMMENT)

(defn to-string
  "Returns the string representation of this attribute.

  returns: the string representation of this attribute - `java.lang.String`"
  ([^javax.swing.text.html.HTML$Attribute this]
    (-> this (.toString))))

==> javax.swing-1.0.3.jar: javax/swing/text/html/HTML$Attribute.clj <==
(ns javax.swing.text.html.HTML$Attribute
  "Typesafe enumeration representing an HTML
  attribute."
  (:refer-clojure :only [require comment defn ->])
  (:import [javax.swing.text.html HTML$Attribute]))

(def *-size
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/SIZE)

(def *-color
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/COLOR)

(def *-clear
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CLEAR)

(def *-background
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/BACKGROUND)

(def *-bgcolor
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/BGCOLOR)

(def *-text
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/TEXT)

(def *-link
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/LINK)

(def *-vlink
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/VLINK)

(def *-alink
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ALINK)

(def *-width
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/WIDTH)

(def *-height
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/HEIGHT)

(def *-align
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ALIGN)

(def *-name
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/NAME)

(def *-href
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/HREF)

(def *-rel
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/REL)

(def *-rev
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/REV)

(def *-title
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/TITLE)

(def *-target
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/TARGET)

(def *-shape
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/SHAPE)

(def *-coords
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/COORDS)

(def *-ismap
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ISMAP)

(def *-nohref
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/NOHREF)

(def *-alt
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ALT)

(def *-id
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ID)

(def *-src
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/SRC)

(def *-hspace
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/HSPACE)

(def *-vspace
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/VSPACE)

(def *-usemap
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/USEMAP)

(def *-lowsrc
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/LOWSRC)

(def *-codebase
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CODEBASE)

(def *-code
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CODE)

(def *-archive
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ARCHIVE)

(def *-value
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/VALUE)

(def *-valuetype
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/VALUETYPE)

(def *-type
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/TYPE)

(def *-class
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CLASS)

(def *-style
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/STYLE)

(def *-lang
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/LANG)

(def *-face
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/FACE)

(def *-dir
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/DIR)

(def *-declare
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/DECLARE)

(def *-classid
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CLASSID)

(def *-data
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/DATA)

(def *-codetype
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CODETYPE)

(def *-standby
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/STANDBY)

(def *-border
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/BORDER)

(def *-shapes
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/SHAPES)

(def *-noshade
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/NOSHADE)

(def *-compact
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/COMPACT)

(def *-start
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/START)

(def *-action
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ACTION)

(def *-method
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/METHOD)

(def *-enctype
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ENCTYPE)

(def *-checked
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CHECKED)

(def *-maxlength
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/MAXLENGTH)

(def *-multiple
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/MULTIPLE)

(def *-selected
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/SELECTED)

(def *-rows
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ROWS)

(def *-cols
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/COLS)

(def *-dummy
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/DUMMY)

(def *-cellspacing
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CELLSPACING)

(def *-cellpadding
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CELLPADDING)

(def *-valign
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/VALIGN)

(def *-halign
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/HALIGN)

(def *-nowrap
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/NOWRAP)

(def *-rowspan
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ROWSPAN)

(def *-colspan
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/COLSPAN)

(def *-prompt
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/PROMPT)

(def *-httpequiv
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/HTTPEQUIV)

(def *-content
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/CONTENT)

(def *-language
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/LANGUAGE)

(def *-version
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/VERSION)

(def *-n
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/N)

(def *-frameborder
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/FRAMEBORDER)

(def *-marginwidth
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/MARGINWIDTH)

(def *-marginheight
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/MARGINHEIGHT)

(def *-scrolling
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/SCROLLING)

(def *-noresize
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/NORESIZE)

(def *-endtag
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/ENDTAG)

(def *-comment
  "Static Constant.

  type: javax.swing.text.html.HTML.Attribute"
  HTML$Attribute/COMMENT)

(defn to-string
  "Returns the string representation of this attribute.

  returns: the string representation of this attribute - `java.lang.String`"
  (^java.lang.String [^javax.swing.text.html.HTML$Attribute this]
    (-> this (.toString))))
